@@ -1,9 +1,11 @@
 #include "mainwindow.h"
 #include "ui_mainwindow.h"
+#include "alarmHandler.h"
 #include "PrayTime.h"
 #include <QSettings>
 #include <QInputDialog>
 #include <iostream>
+#include <QMessageBox>
 using namespace std;
 
 MainWindow::MainWindow(QWidget *parent) :
@@ -50,13 +52,29 @@ if (optionsDialog.isNull()) {
     }
 }
 
+void showAlarmTimes(){
+
+}
+
 void MainWindow::showAbout(){
     qDebug("About");
 }
 
+void MainWindow::showAlarmTimes(){
+    QMessageBox msgbox;
+    msgbox.setText(AlarmHandler::QueryAppAlarms());
+    msgbox.exec();
+}
+void MainWindow::testAzanAlarm(){
+    AlarmHandler::testAzanAlarm();
+}
+
 void MainWindow::createMenu(){
     menuBar()->addAction("Options", this, SLOT(showOptions()));
     menuBar()->addAction("About", this, SLOT(showAbout()));
+    menuBar()->addAction("Check Alarm Times", this, SLOT(showAlarmTimes()));
+    menuBar()->addAction("Test Azan", this, SLOT(testAzanAlarm()));
+
 }
 
 
@@ -124,3 +142,5 @@ void MainWindow::printTimes(QString times){
     }
     exit(0);
 }
+
+
